<?php

if ( !defined( 'ABSPATH' ) ) {
    exit;
}
class WBK_Price_Processor
{
    static function calculate_single_booking_price( $booking, $bookings )
    {
        
        if ( !is_object( $booking ) ) {
            $booking = new WBK_Booking( $booking );
            if ( $booking->get_name() == '' ) {
                return array(
                    'price' => 0,
                );
            }
            
            if ( is_array( $bookings ) ) {
                $booking_temp = array();
                foreach ( $bookings as $booking_id ) {
                    $booking_this = new WBK_Booking( $booking_id );
                    if ( $booking_this->get_name() == '' ) {
                        continue;
                    }
                    $booking_temp[] = $booking_this;
                }
                $bookings = $booking_temp;
            }
        
        }
        
        $service = new WBK_Service( $booking->get_service() );
        if ( $service->get_name() == '' ) {
            return array(
                'price' => 0,
            );
        }
        $default_price = $service->get_price();
        if ( $default_price == 0 ) {
            return array(
                'price' => 0,
            );
        }
        return array(
            'price' => $default_price,
        );
    }
    
    static function get_multiple_booking_price( $booking_ids )
    {
        $total = 0;
        foreach ( $booking_ids as $booking_id ) {
            $booking = new WBK_Booking( $booking_id );
            if ( $booking->get_name() == '' ) {
                continue;
            }
            $total += $booking->get_price() * $booking->get_quantity();
        }
        return $total;
    }
    
    static function get_tax_for_messages()
    {
        $tax_rule = get_option( 'wbk_tax_for_messages', 'paypal' );
        if ( $tax_rule == 'paypal' ) {
            $tax = get_option( 'wbk_paypal_tax', 0 );
        }
        if ( $tax_rule == 'stripe' ) {
            $tax = get_option( 'wbk_stripe_tax', 0 );
        }
        if ( $tax_rule == 'none' ) {
            $tax = 0;
        }
        return $tax;
    }
    
    static function get_total_amount( $sub_total, $tax )
    {
        
        if ( is_numeric( $tax ) && $tax > 0 ) {
            $tax_amount = $sub_total / 100 * $tax;
            $total = $sub_total + $tax_amount;
        } else {
            $total = $sub_total;
        }
        
        return $total;
    }
    
    static function get_tax_amount( $sub_total, $tax )
    {
        
        if ( is_numeric( $tax ) && $tax > 0 ) {
            $tax_amount = $sub_total / 100 * $tax;
        } else {
            $tax_amount = 0;
        }
        
        return $tax_amount;
    }

}